#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_DOT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_DOT_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/dot.hpp>

#endif
